Transforming Sequences
::::::::::::::::::::::

.. toctree::
   :caption: Transforming Sequences
   :maxdepth: 2

   intro-SequenceMutation.rst
   Mutability.rst
   ListDeletion.rst
   ObjectsandReferences.rst
   Aliasing.rst
   CloningLists.rst
   MutatingMethods.rst
   AppendversusConcatenate.rst
   NonmutatingMethodsonStrings.rst
   StringFormatting.rst
   FStrings.rst
   TheAccumulatorPatternwithLists.rst
   TheAccumulatorPatternwithStrings.rst
   WPAccumulatorPatternStrategies.rst
   WPDontMutateAListYouIterateThrough.rst
   Glossary.rst
   Exercises.rst
   week4a1.rst
